==> kubernetes-model-1.0.34-sources.jar: io/fabric8/openshift/api/model/ImageChangeTriggerFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ObjectReference;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;

public class ImageChangeTriggerFluentImpl<T extends ImageChangeTriggerFluent<T>> extends BaseFluent<T> implements ImageChangeTriggerFluent<T>{

     VisitableBuilder<ObjectReference, ?> from;     String lastTriggeredImageID;     Map<String, Object> additionalProperties = new HashMap();
public ImageChangeTriggerFluentImpl(){
    
}
public ImageChangeTriggerFluentImpl( ImageChangeTrigger instance ){
    this.withFrom(instance.getFrom()); this.withLastTriggeredImageID(instance.getLastTriggeredImageID()); 
}

    public ObjectReference getFrom(){
    return this.from!=null?this.from.build():null;
    }
    public T withFrom( ObjectReference from){
    if (from!=null){ this.from= new ObjectReferenceBuilder(from); _visitables.add(this.from);} return (T) this;
    }
    public FromNested<T> withNewFrom(){
    return new FromNestedImpl<T>();
    }
    public FromNested<T> withNewFromLike( ObjectReference item){
    return new FromNestedImpl<T>(item);
    }
    public FromNested<T> editFrom(){
    return withNewFromLike(getFrom());
    }
    public String getLastTriggeredImageID(){
    return this.lastTriggeredImageID;
    }
    public T withLastTriggeredImageID( String lastTriggeredImageID){
    this.lastTriggeredImageID=lastTriggeredImageID; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ImageChangeTriggerFluentImpl that = (ImageChangeTriggerFluentImpl) o;
if (from != null ? !from.equals(that.from) :that.from != null) return false;
if (lastTriggeredImageID != null ? !lastTriggeredImageID.equals(that.lastTriggeredImageID) :that.lastTriggeredImageID != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class FromNestedImpl<N> extends ObjectReferenceFluentImpl<FromNested<N>> implements FromNested<N>{

        private final ObjectReferenceBuilder builder;
    
             FromNestedImpl ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
             FromNestedImpl (){
        this.builder = new ObjectReferenceBuilder(this);
        }
    
            public N endFrom(){
            return and();
        }
            public N and(){
            return (N) ImageChangeTriggerFluentImpl.this.withFrom(builder.build());
        }
    
}


}

==> kubernetes-model-1.0.50-sources.jar: io/fabric8/openshift/api/model/ImageChangeTriggerFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;

public class ImageChangeTriggerFluentImpl<A extends ImageChangeTriggerFluent<A>> extends BaseFluent<A> implements ImageChangeTriggerFluent<A>{

     VisitableBuilder<ObjectReference, ?> from;     String lastTriggeredImageID;
public ImageChangeTriggerFluentImpl(){
    
}
public ImageChangeTriggerFluentImpl( ImageChangeTrigger instance ){
    this.withFrom(instance.getFrom()); this.withLastTriggeredImageID(instance.getLastTriggeredImageID()); 
}

    public ObjectReference getFrom(){
    return this.from!=null?this.from.build():null;
    }
    public A withFrom( ObjectReference from){
    if (from!=null){ this.from= new ObjectReferenceBuilder(from); _visitables.add(this.from);} return (A) this;
    }
    public FromNested<A> withNewFrom(){
    return new FromNestedImpl();
    }
    public FromNested<A> withNewFromLike( ObjectReference item){
    return new FromNestedImpl(item);
    }
    public FromNested<A> editFrom(){
    return withNewFromLike(getFrom());
    }
    public String getLastTriggeredImageID(){
    return this.lastTriggeredImageID;
    }
    public A withLastTriggeredImageID( String lastTriggeredImageID){
    this.lastTriggeredImageID=lastTriggeredImageID; return (A) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ImageChangeTriggerFluentImpl that = (ImageChangeTriggerFluentImpl) o;
if (from != null ? !from.equals(that.from) :that.from != null) return false;
if (lastTriggeredImageID != null ? !lastTriggeredImageID.equals(that.lastTriggeredImageID) :that.lastTriggeredImageID != null) return false;
return true;

    }

    public class FromNestedImpl<N> extends ObjectReferenceFluentImpl<FromNested<N>> implements FromNested<N>{

        private final ObjectReferenceBuilder builder;
    
             FromNestedImpl (){
        this.builder = new ObjectReferenceBuilder(this);
        }
             FromNestedImpl ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
    
            public N endFrom(){
            return and();
        }
            public N and(){
            return (N) ImageChangeTriggerFluentImpl.this.withFrom(builder.build());
        }
    
}


}
